/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("net.jazz.ajax.core.internal.UriMonitor");

dojo.require("net.jazz.ajax.core.internal.IEUriMonitor");
dojo.require("net.jazz.ajax.toolbox.lang.internal.Lang");

//
// Aliases
//

var checkNotNull  = net.jazz.ajax.toolbox.lang.checkNotNull;
var checkNotEmpty = net.jazz.ajax.toolbox.lang.checkNotEmpty;

var IEUriMonitor  = net.jazz.ajax.core.internal.IEUriMonitor;
	
function UriMonitor(onLocationChangeFn) {
	// summary:
	//		Monitors the browser's location (URI) for changes. If a change is
	//		detected, calls the function specified by onLocationChangeFn with
	//		a dojo.uri.Uri object for the new URI.
	checkNotNull(onLocationChangeFn, "onLocationChangeFn");
	
	// initialize recentLocationHash
	var recentLocationHash = window.location.hash;
	
	this.pollLocation = function() {
		// bail out early if the value after the hash hasn't changed
		if(window.location.hash === recentLocationHash) {
			return;
		}
		// otherwise, save a reference to the new current hash, and process
		// the new URI
		recentLocationHash = window.location.hash;
		onLocationChangeFn(new dojo._Url(window.location.href));
	}
	
	// continuously monitor the browser's URI for changes
	setInterval(this.pollLocation, 200);
}

net.jazz.ajax.core.internal.UriMonitor = UriMonitor;

function createUriMonitor(onUrlChangeFn) {
	// summary:
	//		Creates and returns a new URI monitor.
	checkNotNull(onUrlChangeFn, "onUrlChangeFn");

	if (dojo.isIE) {
		return new IEUriMonitor(onUrlChangeFn);
	}
	
	return new UriMonitor(onUrlChangeFn);
}

net.jazz.ajax.core.internal.createUriMonitor = createUriMonitor;

})();